/*
 * Copyright (c) 2003 Christian Loose <christian.loose@hamburg.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#include "cvsserviceutils.h"

#include <kshell.h>
#include <qstring.h>
#include <qstringlist.h>

QString CvsServiceUtils::joinFileList(const QStringList &files)
{
    QString result;

    QStringList::ConstIterator it = files.begin();
    QStringList::ConstIterator end = files.end();

    for (; it != end; ++it) {
        result += KShell::quoteArg(*it);
        result += ' ';
    }

    if (!result.isEmpty())
        result.truncate(result.length() - 1);

    return result;
}
